import 'reflect-metadata'
import express from "express"
import {JWTUserPayload, TPostStatus} from "../types"
import {hasValidationErrors, resultJson} from "../includes"
import {body, param, query} from "express-validator"
import {Container} from "typedi"
import {AdminService} from "../services/admin-service"
import {PostModel} from "../models/post-model"
import expressAsyncHandler from "express-async-handler"

let adminService = Container.get(AdminService)
let postModel = Container.get(PostModel)
let adminRouter = express.Router()
adminRouter.use((req: express.Request, res: express.Response, next) => {
    if ((req.user as JWTUserPayload).role < 2) {
        res.json(resultJson.error('您需要管理员权限来造访该接口'))
    } else {
        next()
    }
})
adminRouter.get('/list/:status',
    param('status').isIn([1, 2, 3]).withMessage('Post状态仅支援1,2,3'),
    query('page').default(1).isInt({min: 1}).withMessage('页码必须>=1'),
    expressAsyncHandler(async (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(await adminService.list(Number(req.params.status) as TPostStatus, Number(req.query.page)))
    })
)
adminRouter.post('/setStatus',
    body('id').isInt().bail().custom(async input => {
        let post = await postModel.findPostById(input)
        if (!post) {
            throw new Error('Post ID不存在')
        }
    }),
    body('status').isIn([1, 2, 3]).withMessage('Post状态仅支援1,2,3'),
    expressAsyncHandler(async (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(await adminService.setStatus(req.body.id, req.body.status))
    })
)

export {adminRouter}
