import 'reflect-metadata'
import express from "express"
import {Container} from "typedi"
import {UserService} from "../services/user-service"
import {body, validationResult,} from "express-validator"
import {hasValidationErrors} from "../includes"
import {JWTUserPayload} from "../types"
import expressAsyncHandler from "express-async-handler"

let userService = Container.get(UserService)

let userRouter = express.Router()
userRouter.post('/login',
    body('username').notEmpty().withMessage('请输入使用者名称'),
    body('password').notEmpty().withMessage('请输入密码'),
    expressAsyncHandler(async (req: express.Request, res: express.Response) => {
        if (hasValidationErrors(req, res)) return
        res.json(await userService.login(req.body.username, req.body.password))
    })
)
userRouter.get('/me',expressAsyncHandler(async (req:express.Request,res:express.Response)=>{
    res.json(await userService.me(req.user as JWTUserPayload))
}))

export {userRouter}
