import 'reflect-metadata'
import {Inject, Service} from "typedi"
import {UserModel} from "../models/user-model"
import {getAxiosInstance, resultJson} from "../includes"
import {strEnc} from "../helpers/des"
import qs from 'qs'
import jwt from "jsonwebtoken"
import {appConfig} from "../config"
import {JWTUserPayload} from "../types"

@Service()
export class UserService {
    @Inject()
    userModel!: UserModel

    async login(username: string, password: string) {
        let casUrl = 'https://pass.sdu.edu.cn/cas/login?service=https%3A%2F%2Fservice.sdu.edu.cn%2Ftp_up%2F'
        let axios = getAxiosInstance()
        let resp = await axios.get(casUrl)
        if (resp.status != 200) {
            return resultJson.error('无法连线至认证伺服器')
        }
        let ticket = /name="lt" value="(.*?)"/.exec(resp.data)?.[1] || null
        if (!ticket) {
            return resultJson.error('无法取得ticket')
        }
        let rsa = strEnc(username + password + ticket, '1', '2', '3')
        resp = await axios.post(casUrl, qs.stringify({
            rsa,
            ul: username.length.toString(),
            pl: password.length.toString(),
            execution: 'e1s1',
            _eventId: 'submit'
        }))
        if (resp.status != 200) {
            return resultJson.error('无法连线至认证伺服器')
        }
        if (!resp.data.includes('退出登录')) {
            return resultJson.error('使用者名称或密码有误，请重新输入')
        }
        let realName = / <\/p> <span class="tit">(.*?)</.exec(resp.data)?.[1]!
        await this.userModel.insertUser({
            username,
            realName,
            role: 1
        })
        let user = await this.userModel.findUserByUsername(username)
        let token = 'Bearer '
            + jwt.sign({id: user?.id, role: user?.role}, appConfig.jwtSecret, {algorithm: 'HS256'})
        return resultJson.success(token)
    }

    async me(jwtUserPayload: JWTUserPayload) {
        let user=await this.userModel.findUserById(jwtUserPayload.id)
        return resultJson.success(user)
    }
}
